require "scoverage/version"
require "oga"

module Scoverage

  def self.colorize(text, color_code)
    "\e[#{color_code}m#{text}\e[0m"
  end
  def self.red(text); colorize(text, 31); end
  def self.green(text); colorize(text, 32); end
  def self.yellow(text); colorize(text, 33); end

  def self.rate_text(rate)
    if rate >= 70
      green(rate)
    elsif rate >= 40
      yellow(rate)
    else
      red(rate)
    end
  end

  def self.init(filename)
    handle = File.open(File.expand_path("#{filename}", Dir.pwd))
    xml = Oga.parse_xml(handle)
    all = xml.children.first.get('statement-rate').to_f
    xml.xpath('scoverage/packages/package').each do |package|
      package_rate = package.get('statement-rate').to_f
      puts rate_text(package_rate) + " % - " + package.get('name') + " "
      package.xpath('classes/class').each do |clazz|
        rate = clazz.get('statement-rate').to_f
        puts '  ' + rate_text(rate) + " % \t " + clazz.get('name')
      end
    end
    puts
    puts "===================="
    puts "All packages: #{rate_text(all)} %"
    puts "===================="
  end
end
